---
title: "CIS AWS v3.0"
description: "Terraform compliance scanning for CIS AWS v3.0 — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Community" variant="success" />
<Badge text="Benchmark" variant="tip" />

**Issuing body:** [CIS](https://www.cisecurity.org)
**Jurisdiction:** Global — Global
**Countries:** Worldwide


## Assessment

Assess your infrastructure against CIS AWS for free at any tier:

```bash
complyform assess --frameworks=cis_aws
```

## Remediation

Remediation is included free at all tiers.

```bash
complyform remediate --frameworks=cis_aws
```

## Related Frameworks

- [SOC 2 Type II](/frameworks/soc2)
- [CIS GCP v2.0](/frameworks/cis_gcp)
- [CIS Azure v2.0](/frameworks/cis_azure)
